@@ -10,6 +10,8 @@ def instrument_logging(module):
                 ctx = TraceContextManager.getLocalContext()
                 if ctx:
                     setattr(record, "txid", str(ctx.id))
+                else:
+                    setattr(record, "txid", None)
             return fn(*args, **kwargs)
         
         return trace
