@@ -8,7 +8,7 @@ from whatap.util.hexa32 import Hexa32
 
 from whatap.util.linked_map import LinkedMap
 from resource import getrusage, RUSAGE_SELF
-
+import os
 
 class TraceContext(object):
     transfer_id = None
@@ -22,7 +22,10 @@ class TraceContext(object):
 
         self.id = TraceContextManager.getId()
         self.thread = threading.current_thread()
-        self.thread_id = TraceContextManager.start(self)
+        self.thread_id = self.thread.ident
+        TraceContextManager.start(self)
+        
+        self.pid = os.getpid()
 
         self.start_time = 0
         self.start_cpu = 0
