@@ -107,4 +107,8 @@ DEFINITION = {
     'logging':[
         ('logging.handlers','instrument_logging'),
     ],
+    'application_fastapi': [
+        ('fastapi.routing', 'instrument'),
+        ('fastapi.dependencies.utils', 'instrument_util'),
+    ],
 }
